# AWS CDK CloudFormation Constructs for MongoDB::Atlas::DatabaseUser

The databaseUsers resource lets you retrieve, create and modify the MongoDB users in your cluster. Each user has a set of roles that provide access to the project?s databases. A user?s roles apply to all the clusters in the project: if two clusters have a products database and a user has a role granting read access on the products database, the user has that access on both clusters.

## License

Distributed under the Apache-2.0 License.
